%define _disable_ld_no_undefined	%nil

%define major		2
%define shortname	speechd
%define libname		%mklibname %{shortname} %{major}
%define devname		%mklibname %{shortname} -d

%define build_alsa	1
%define build_pulse	1
%define build_nas	1
%define build_espeak	1

%{?_without_alsa: %{expand: %%global build_alsa 0}}
%{?_with_alsa: %{expand: %%global build_alsa 1}}

%{?_without_pulse: %{expand: %%global build_pulse 0}}
%{?_with_pulse: %{expand: %%global build_pulse 1}}

%{?_without_nas: %{expand: %%global build_nas 0}}
%{?_with_nas: %{expand: %%global build_nas 1}}

%{?_without_espeak: %{expand: %%global build_espeak 0}}
%{?_with_espeak: %{expand: %%global build_espeak 1}}

Name:		speech-dispatcher
Version:	0.7.1
Release:	%mkrel 4
Summary:	Speech Dispatcher provides a device independent layer for speech synthesis
Group:		System/Libraries
License:	GPLv2
URL:		http://www.freebsoft.org/speechd
Source0:	http://www.freebsoft.org/pub/projects/speechd/%{name}-%{version}.tar.gz
# systemd unit from Fedora
Source1:	speech-dispatcher.service
Source2:	speech-dispatcher.logrotate
Source4:	speech-dispatcher-user-pulse.example
Patch1:		speech-dispatcher-0.6.7-fix-str-fmt.patch
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%if %build_alsa
BuildRequires:	libalsa-devel
%endif

%if %build_pulse
BuildRequires:	pulseaudio-devel
%endif

%if %build_nas
BuildRequires:	libnas-devel
%endif

%if %build_espeak
BuildRequires:	libespeak-devel
%endif

BuildRequires:	dotconf-devel
BuildRequires:	python-devel
BuildRequires:	texinfo

%description
This is the Speech Dispatcher project (speech-dispatcher). It is a part of the
Free(b)soft project, which is intended to allow blind and visually impaired
people to work with computer and Internet based on free software.

%post
%_install_info %{name}.info
%_install_info spd-say.info
%_install_info ssip.info
%_install_info %{name}-cs.info
%_post_service speech-dispatcherd

%preun
%_remove_install_info %{name}.info
%_remove_install_info spd-say.info
%_remove_install_info ssip.info
%_remove_install_info %{name}-cs.info
%_preun_service speech-dispatcherd

%files
%doc AUTHORS NEWS README INSTALL TODO 
%doc ChangeLog speech-dispatcher-user-pulse.example
%{_bindir}/cli*
%{_bindir}/connection_recovery
%{_bindir}/spd-say
%{_bindir}/spd_long_message
%{_bindir}/spd_run_test
%{_bindir}/spdsend
%{_bindir}/%{name}
%{_unitdir}/speech-dispatcherd.service
%config %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/speech-dispatcher/speechd.conf
%config(noreplace) %{_sysconfdir}/%{name}/clients/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/modules/*.conf
%dir %{_sysconfdir}/%{name}
%{_libdir}/%{name}-modules
%{_datadir}/sounds/%{name}
%{_infodir}/*
%{_logdir}/%{name}
%{_datadir}/%{name}/

#--------------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Conflicts:	%{name} < 0.7.1

%description -n	%{libname}
This package provides the shared libraries for Speech Dispatcher.

%files -n %{libname}
%doc COPYING ChangeLog
%{_libdir}/libspeechd.so.%{major}*
%{_libdir}/%{name}/libsdaudio.so.%{major}*

#--------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains development files for %{name}.

%files -n %{devname}
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/%{name}/lib*.so

#--------------------------------------------------------------------------

%package -n python-%{shortname}
Summary:	A Python library for communication with Speech Dispatcher
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%description -n python-%{shortname}
This package provides a Python library for communication 
with Speech Dispatcher.

%files -n python-%{shortname}
%doc ChangeLog
%{_bindir}/spd-conf
%{_datadir}/sounds/%{name}/test.wav
%{python_sitelib}/speechd*

#--------------------------------------------------------------------------

%prep
%setup -q
%patch1 -p0

cp -p %SOURCE4 .

%build
export am_cv_python_pyexecdir=%{python_sitelib}
%configure2_5x \
	--disable-static \
%if %build_alsa
	--with-alsa \
%else
	--without-alsa \
%endif
%if %build_pulse
	--with-pulse \
%else
	--without-pulse \
%endif
%if %build_nas
	--with-nas \
%else
	--without-nas \
%endif
%if %build_espeak
	--with-espeak
%else
	--without-espeak
%endif

%make

%install
rm -rf %buildroot
%makeinstall_std

# rename some executables
mv %{buildroot}%{_bindir}/long_message %{buildroot}%{_bindir}/spd_long_message
mv %{buildroot}%{_bindir}/run_test %{buildroot}%{_bindir}/spd_run_test

# speech-dispatcher service
install -Dm 0644 %SOURCE1 %{buildroot}%{_unitdir}/speech-dispatcherd.service

# fix perm in _test.py
chmod +x %{buildroot}%{python_sitelib}/speechd/_test.py

# logrotate install
install -Dm 0644 %SOURCE2 %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# create the needed directory for logs
install -d -m 0755 %{buildroot}%{_logdir}/%{name}

# remove flite module from the default configuration in speechd.conf
sed -i -e "210 s:AddModule:#AddModule:g" %{buildroot}%{_sysconfdir}/%{name}/speechd.conf

# we don't wat these
find %{buildroot} -name "*.la" -delete


%changelog

* Mon Jan 14 2013 umeabot <umeabot> 0.7.1-4.mga3
+ Revision: 382480
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Apr 28 2012 tmb <tmb> 0.7.1-3.mga2
+ Revision: 233869
- Require rpm-helper >= 0.24.8-1 for systemd support

* Thu Jan 26 2012 fwang <fwang> 0.7.1-2.mga2
+ Revision: 201778
- correct br
- rebuild for new dotconf

* Wed Dec 21 2011 wally <wally> 0.7.1-1.mga2
+ Revision: 185545
- new version 0.7.1
- rediff P1, drop P0,P2 and P3
- add systemd support (from Fedora)
- drop sysvinit support
- move some libs from main pkg to lib pkg
- add python fix (from Mdv)
- clean .spec a bit

* Fri May 20 2011 mikala <mikala> 0.6.7-4.mga1
+ Revision: 99939
- Add back the configuration files in /usr/share/speed-dispatcher/conf
 since python-speechd is using them...

* Thu Jan 20 2011 ahmad <ahmad> 0.6.7-3.mga1
+ Revision: 25816
- imported package speech-dispatcher

